@@ -1,3 +1,5 @@
 from .load_dataset import load_dataset
 from .parse_dataset import parse_dataset
 from .verify_ml import verify_ml_dataset
+from .recommend_model import recommend_model
+from .automl import automl
